@@ -30,6 +30,8 @@
 
 #include "gconf-stock-icons.h"
 
+G_DEFINE_TYPE(GConfSearchDialog, gconf_search_dialog, GTK_TYPE_DIALOG)
+
 static void
 gconf_search_dialog_response (GtkDialog *dialog, gint response_id)
 {
@@ -178,30 +180,6 @@ gconf_search_dialog_init (GConfSearchDialog *dialog)
 	gtk_widget_show_all (hbox);
 }
 
-GType
-gconf_search_dialog_get_type (void)
-{
-	static GType object_type = 0;
-
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (GConfSearchDialogClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) gconf_search_dialog_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (GConfSearchDialog),
-			0,              /* n_preallocs */
-			(GInstanceInitFunc) gconf_search_dialog_init
-		};
-
-		object_type = g_type_register_static (GTK_TYPE_DIALOG, "GConfSearchDialog", &object_info, 0);
-	}
-
-	return object_type;
-}
-
 GtkWidget *
 gconf_search_dialog_new (GtkWindow *parent)
 {
